@@ -17,6 +17,8 @@ type IPTablesHelper interface {
 	// ClearChain removes all rules in the specified table/chain.
 	// If the chain does not exist, a new one will be created
 	ClearChain(string, string) error
+	// DeleteChain deletes the chain in the specified table.
+	DeleteChain(string, string) error
 	// NewChain creates a new chain in the specified table
 	NewChain(string, string) error
 	// Exists checks if given rulespec in specified table/chain exists
@@ -136,6 +138,24 @@ func (f *FakeIPTables) ClearChain(tableName, chainName string) error {
 	return f.NewChain(tableName, chainName)
 }
 
+// DeleteChain deletes the chain in the specified table.
+// The chain must be empty
+func (f *FakeIPTables) DeleteChain(tableName, chainName string) error {
+	table, err := f.getTable(tableName)
+	if err != nil {
+		return err
+	}
+	if chain, err := table.getChain(chainName); err == nil {
+		if len(chain) != 0 {
+			return fmt.Errorf("chain must be empty")
+		}
+		delete((*table), chainName)
+		return nil
+	} else {
+		return err
+	}
+}
+
 // Exists checks if given rulespec in specified table/chain exists
 func (f *FakeIPTables) Exists(tableName, chainName string, rulespec ...string) (bool, error) {
 	table, err := f.getTable(tableName)
